import request from "@/utils/request"

// 刷新令牌
export const refreshToken = (refreshToken) => {
  return request({
    url: '/app-api/menduner/system/auth/refresh-token',
    method: "POST",
    params: {
      refreshToken
    },
    custom: {
      showLoading: false,
      showError: false
    }
  })
}

// 发送手机验证码
export const sendSmsCode = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/send-sms-code',
    method: "POST",
    data,
    custom: {
      loadingMsg: '发送中',
      showSuccess: true,
      successMsg: '发送成功'
    }
  })
}

// 短信登录
export const smsLogin = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/sms-login',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 微信小程序的一键登录
export const weChatLogin = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/weixin-mini-app-login',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 短信登录
export const userRegister = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/register',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}


// 密码登录
export const passwordLogin = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/login',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 二维码扫码用户注册并登录
export const shareUserRegister = (data) => {
  return request({
    url: '/app-api/menduner/system/auth/register',
    method: 'POST',
    data,
    custom: {
      showLoading: false
    }
  })
}

// 退出登录
export const logout = () => {
  return request({
    url: '/app-api/menduner/system/auth/logout',
    method: 'POST',
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 字典
export const getDictData = (params) => {
  return request({
    url: '/app-api/system/dict-data/type',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取行业列表
export const getIndustryListData = (params) => {
  return request({
    url: '/app-api/menduner/system/industry/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取技能列表
export const getSkillList = () => {
  return request({
    url: '/app-api/menduner/system/skill/list',
    method: 'GET',
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取行业树形
export const getIndustryTreeData = (params) => {
  return request({
    url: '/app-api/menduner/system/industry/get/tree',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取地区列表
export const getAreaListData = (params) => {
  return request({
    url: '/app-api/menduner/system/area/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取地区获取地区map
export const getAreaMapData = (params) => {
  return request({
    url: '/app-api/menduner/system/area/map',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获得职位类型
export const getPositionTreeData = (params) => {
  return request({
    url: '/app-api/menduner/system/position/get/tree',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取职位列表
export const getPositionData = (params) => {
  return request({
    url: '/app-api/menduner/system/position/list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获取区域树形
export const getAreaTreeData = () => {
  return request({
    url: '/app-api/menduner/system/area/get/tree',
    method: 'GET',
    custom: {
      showLoading: false,
      auth: false
    }
  })
}




// 同步最近会话
export const getConversationSync = async (data) => {
  return request({
    url: '/app-api/im/conversation/sync',
    method: 'POST',
    data,
    custom: {
      openEncryption: true,
      showLoading: false,
      auth: true
    }
  })
}


// 获取聊天秘钥信息
export const getChatKey = async (data) => {
  return request({
    url: '/app-api/im/user/get',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 同步最近会话
export const getMessageSync = async (data) => {
  return request({
    url: '/app-api/im/im/channel/messagesync',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}
// 设置最近会话未读数量
export const setUnread = async (data) => {
  return request({
    url: '/app-api/im/conversations/setUnread',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}
// 设置最近会话未读数量
export const deleteConversation = async (data) => {
  return request({
    url: '/app-api/im/conversation/delete',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}
// 获取type类型聊天记录
export const getMessageType = async (data) => {
  return request({
    url: '/app-api/im/im/history/messages',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 求职端-根据邀请人id获取面试邀约列表
export const getInterviewInviteListByInviteUserId = async (inviteUserId) => {
  return request({
    url: `/app-api/menduner/system/interview-invite/get/list/by/${inviteUserId}`,
    method: 'GET',
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 内容管理-广告
export const getWebContent = async () => {
  return request({
    url: `/app-api/menduner/system/web-content/get?id=1`,
    method: 'GET',
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 联系我们
// 提交猎寻服务
export const huntSubmit = async (data) => {
  return request({
    url: '/admin-api/menduner/system/hunt/submit',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: false
    }
  })
}

// 获得微信小程订阅模板列表
// export const getSubscribeTemplateList = async () => {
//   return request({
//     url: `/app-api/menduner/system/social-user/get-subscribe-template-list`,
//     method: 'GET',
//     custom: {
//       showLoading: false,
//       auth: false
//     }
//   })
// }

// 求职端交易订单  创建
export const orderCreated = async (data) => {
  return request({
    // url: '/app-api/menduner/system/trade/order/create',
    url: '/app-api/menduner/system/trade/order/wx-program/create',
    method: 'POST',
    data,
    custom: {
      openEncryption: true,
      showLoading: false,
      auth: true
    }
  })
}

// 求职端交易订单  创建
export const getOrder = async (params) => {
  return request({
    url: '/app-api/menduner/system/trade/order/get/unpaid',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 获得社交用户
export const getSocialUser = async (type) => {
  return request({
    url: `/app-api/menduner/system/social-user/get?type=${type}`,
    method: 'GET',
    // params,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

//  获得支付订单 (轮巡支付状态)
export const getOrderPayStatus = async (params) => {
  return request({
    url: '/app-api/pay/order/get',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 获得指定应用的开启的支付渠道编码列表
export const getEnableCodeList = async (params) => {
  return request({
    url: '/app-api/pay/channel/get-enable-code-list',
    method: 'GET',
    params,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 提交支付订单
export const payOrderSubmit = async (data) => {
  return request({
    url: '/app-api/pay/order/submit',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}

// 社交绑定，使用 code 授权码
export const socialUserBind = async (data) => {
  return request({
    url: '/app-api/menduner/system/social-user/bind',
    method: 'POST',
    data,
    custom: {
      showLoading: false,
      auth: true
    }
  })
}
